@@ -1,7 +1,7 @@
 ;;; gnus-salt.el --- alternate summary mode interfaces for Gnus
 
-;; Copyright (C) 1996, 1997, 1998, 1999, 2001
-;;        Free Software Foundation, Inc.
+;; Copyright (C) 1996, 1997, 1998, 1999, 2001, 2002, 2003, 2004,
+;;   2005, 2006 Free Software Foundation, Inc.
 
 ;; Author: Lars Magne Ingebrigtsen <larsi@gnus.org>
 ;; Keywords: news
@@ -20,8 +20,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
@@ -128,8 +128,7 @@ It accepts the same format specs that `gnus-summary-line-format' does."
       ;; Set up the menu.
       (when (gnus-visual-p 'pick-menu 'menu)
 	(gnus-pick-make-menu-bar))
-      (add-minor-mode 'gnus-pick-mode " Pick" gnus-pick-mode-map
-			   nil 'gnus-pick-mode)
+      (add-minor-mode 'gnus-pick-mode " Pick" gnus-pick-mode-map)
       (gnus-run-hooks 'gnus-pick-mode-hook))))
 
 (defun gnus-pick-setup-message ()
@@ -230,7 +229,7 @@ This must be bound to a button-down mouse event."
   (let* ((echo-keystrokes 0)
 	 (start-posn (event-start start-event))
 	 (start-point (posn-point start-posn))
-	 (start-line (1+ (count-lines 1 start-point)))
+         (start-line (1+ (count-lines (point-min) start-point)))
 	 (start-window (posn-window start-posn))
 	 (bounds (gnus-window-edges start-window))
 	 (top (nth 1 bounds))
@@ -266,17 +265,18 @@ This must be bound to a button-down mouse event."
 	     ;; Are we moving within the original window?
 	     ((and (eq (posn-window end) start-window)
 		   (integer-or-marker-p end-point))
-	;; Go to START-POINT first, so that when we move to END-POINT,
+	      ;; Go to START-POINT first, so that when we move to END-POINT,
 	      ;; if it's in the middle of intangible text,
 	      ;; point jumps in the direction away from START-POINT.
 	      (goto-char start-point)
 	      (goto-char end-point)
 	      (gnus-pick-article)
 	      ;; In case the user moved his mouse really fast, pick
-	    ;; articles on the line between this one and the last one.
-	      (let* ((this-line (1+ (count-lines 1 end-point)))
+	      ;; articles on the line between this one and the last one.
+	      (let* ((this-line (1+ (count-lines (point-min) end-point)))
 		     (min-line (min this-line start-line))
 		     (max-line (max this-line start-line)))
+		;; Why not use `forward-line'?  --Stef
 		(while (< min-line max-line)
 		  (goto-line min-line)
 		  (gnus-pick-article)
@@ -361,8 +361,7 @@ This must be bound to a button-down mouse event."
       ;; Set up the menu.
       (when (gnus-visual-p 'binary-menu 'menu)
 	(gnus-binary-make-menu-bar))
-      (add-minor-mode 'gnus-binary-mode " Binary"
-			   gnus-binary-mode-map nil 'gnus-binary-mode)
+      (add-minor-mode 'gnus-binary-mode " Binary" gnus-binary-mode-map)
       (gnus-run-hooks 'gnus-binary-mode-hook))))
 
 (defun gnus-binary-display-article (article &optional all-header)
@@ -495,7 +494,7 @@ Two predefined functions are available:
     (gnus-set-work-buffer)
     (gnus-tree-node-insert (make-mail-header "") nil)
     (setq gnus-tree-node-length (1- (point))))
-  (gnus-run-hooks 'gnus-tree-mode-hook))
+  (gnus-run-mode-hooks 'gnus-tree-mode-hook))
 
 (defun gnus-tree-read-summary-keys (&optional arg)
   "Read a summary buffer key sequence and execute it."
@@ -787,7 +786,7 @@ Two predefined functions are available:
 	  (setq beg (point))
 	  (forward-char -1)
 	  ;; Draw "-" lines leftwards.
-	  (while (and (> (point) 1)
+	  (while (and (not (bobp))
 		      (eq (char-after (1- (point))) ? ))
 	    (delete-char -1)
 	    (insert (car gnus-tree-parent-child-edges))
@@ -858,7 +857,8 @@ Two predefined functions are available:
 		(gnus-extent-detached-p gnus-selected-tree-overlay))
 	;; Create a new overlay.
 	(gnus-overlay-put
-	 (setq gnus-selected-tree-overlay (gnus-make-overlay 1 2))
+	 (setq gnus-selected-tree-overlay
+	       (gnus-make-overlay (point-min) (1+ (point-min))))
 	 'face gnus-selected-tree-face))
       ;; Move the overlay to the article.
       (gnus-move-overlay
@@ -1007,7 +1007,7 @@ The following commands are available:
   (buffer-disable-undo)
   (setq buffer-read-only t)
   (make-local-variable 'gnus-carpal-attached-buffer)
-  (gnus-run-hooks 'gnus-carpal-mode-hook))
+  (gnus-run-mode-hooks 'gnus-carpal-mode-hook))
 
 (defun gnus-carpal-setup-buffer (type)
   (let ((buffer (symbol-value (intern (format "gnus-carpal-%s-buffer" type)))))
@@ -1062,4 +1062,5 @@ The following commands are available:
 
 (provide 'gnus-salt)
 
+;; arch-tag: 35449164-77b3-4398-bcbd-a2e3e998f810
 ;;; gnus-salt.el ends here
